@@ -14,10 +14,10 @@ class LogType(enum.Enum):
 
 class LogWriter():
     def __init__(self, filepath, encoding):
-        self.debug_num,
-        self.info_num,
-        self.warn_num,
-        self.error_num,
+        self.debug_num,\
+        self.info_num,\
+        self.warn_num,\
+        self.error_num,\
         self.fatal_num = 0, 0, 0, 0, 0
 
         self.filepath = filepath
